@@ -258,6 +258,37 @@ impl Pile {
         mappie
     }
 
+    /// Takes a `Pile` and returns a `HashMap` with the key as each `Suit` in the `Pile` with the values
+    /// as a `Pile` of the cards for that Suit.
+    ///
+    /// TODO: Make generic
+    #[must_use]
+    pub fn map_by_rank(&self) -> HashMap<Rank, Pile> {
+        // WONDERING IF THIS WAY IS BETTER
+        // pub fn map_by_rank(&self) -> HashMap<Rank, Pile> {
+        //     let mut s: HashMap<Rank, Pile> = HashMap::default();
+        //     for card in self.clone().into_iter() {
+        //         if s.contains_key(&card.rank) {
+        //             s.get_mut(&card.rank).unwrap().push(card);
+        //         } else {
+        //             s.insert(card.rank, Pile::from_vector(vec![card]));
+        //         }
+        //     }
+        //     s
+        // }
+        let mut mappie: HashMap<Rank, Pile> = HashMap::new();
+        for rank in self.ranks() {
+            let pile = self
+                .0
+                .clone()
+                .into_iter()
+                .filter(|c| c.rank == rank)
+                .collect();
+            mappie.insert(rank, pile);
+        }
+        mappie
+    }
+
     /// Takes a `Pile` and returns a `HashMap` with the key as each `Suit` in the `Pile` with the values
     /// as a `Pile` of the cards for that Suit.
     #[must_use]
@@ -348,6 +379,16 @@ impl Pile {
         }
     }
 
+    /// Returns a `Pile` with a geometric binary shift operation performed on the
+    /// existing one. Used for frequency sorting on a `Pile` of `Cards`.
+    #[must_use]
+    pub fn shift_rank_weight_left(&self, i: usize) -> Pile {
+        self.clone()
+            .into_iter()
+            .map(|c| c.shift_rank_weight_left(i))
+            .collect()
+    }
+
     #[must_use]
     pub fn short_index_for_suit(&self, suit: Suit) -> String {
         let cards = Pile::from_vector(self.cards_by_suit(suit));
@@ -355,6 +396,9 @@ impl Pile {
         suit.symbol().as_str().to_owned() + " " + &cards.rank_indexes_with_separator(" ")
     }
 
+    /// Returns a Vector of index strings, one for each `Suit` in the `Pile`, that starts with
+    /// the `Card's` `Suit` symbol followed by the `Rank` for each `Card` in the `Pile`.
+    /// This is useful for creating displays such as the ones in Bridge columns.
     #[must_use]
     pub fn short_suit_indexes(&self) -> Vec<String> {
         self.sort()
@@ -371,6 +415,8 @@ impl Pile {
         self.short_suit_indexes().join("\n")
     }
 
+    /// Returns a new, sorted `Pile`. Sorting is determined by the weight set for
+    /// each `Card` in the `Pile`.
     #[must_use]
     pub fn shuffle(&self) -> Pile {
         let mut shuffled = self.clone();
@@ -394,6 +440,44 @@ impl Pile {
         self.0.reverse();
     }
 
+    /// Takes the existing `Pile` and returns a new one with a sort emphasizing
+    /// the frequency of the cards passed in. The more `Cards` of a specific
+    /// `Rank`, the higher the weight each `Card` is given.
+    #[allow(clippy::missing_panics_doc)]
+    #[must_use]
+    pub fn sort_by_frequency(&self) -> Pile {
+        let mut v: Vec<Pile> = Vec::default();
+        let mappie = self.map_by_rank();
+        for rank in mappie.keys() {
+            let un = mappie.get(rank).unwrap();
+            v.push(un.shift_rank_weight_left(un.len()));
+        }
+        Pile::pile_on(v).sort()
+    }
+
+    /// Takes the entire Pile and returns a new Pile where the cards in it are Rank weighted first
+    /// instead of Suit weighted first. Useful for when displays need to sort by Rank.
+    ///
+    /// ```
+    /// use cardpack::{Card, CLUBS, HEARTS, JACK, QUEEN, Pile};
+    ///
+    /// let qh = Card::from_index_strings(QUEEN, HEARTS);
+    /// let jh = Card::from_index_strings(JACK, HEARTS);
+    /// let qc = Card::from_index_strings(QUEEN, CLUBS);
+    /// let jc = Card::from_index_strings(JACK, CLUBS);
+    ///
+    /// let pile = Pile::from_vector(vec![qh, jh, jc, qc]);
+    /// let rank_weighted = pile.convert_to_rank_weighted();
+    ///
+    /// println!("{}", rank_weighted.sort());
+    /// ```
+    /// This will print out `QH QC JH JC`.
+    ///
+    #[must_use]
+    pub fn convert_to_rank_weighted(&self) -> Pile {
+        self.0.iter().map(Card::to_rank_weight).collect()
+    }
+
     /// Returns a sorted collection of the unique Suits in a Pile.
     #[must_use]
     pub fn suits(&self) -> Vec<Suit> {
@@ -680,6 +764,23 @@ mod pile_tests {
         let v = pile.cards_by_suit(qc.suit);
 
         assert_eq!(expected, v);
+
+        format!("{}", pile.convert_to_rank_weighted().sort());
+    }
+
+    #[test]
+    fn convert_to_rank_sort() {
+        let qh = Card::from_index_strings(QUEEN, HEARTS);
+        let jh = Card::from_index_strings(JACK, HEARTS);
+        let qc = Card::from_index_strings(QUEEN, CLUBS);
+        let jc = Card::from_index_strings(JACK, CLUBS);
+
+        let pile = Pile::from_vector(vec![qh, jh, jc, qc]);
+
+        assert_eq!(
+            "QH QC JH JC",
+            format!("{}", pile.convert_to_rank_weighted().sort())
+        );
     }
 
     #[test]
@@ -854,6 +955,22 @@ mod pile_tests {
         assert!(mappie.get(&Rank::new(EIGHT)).is_none());
     }
 
+    #[test]
+    fn pile_by_rank() {
+        let pile = Pile::french_deck()
+            .pile_by_index(&["QS", "9S", "QC", "QH", "QD"])
+            .unwrap();
+
+        let ranked = pile.map_by_rank();
+        let queens = ranked.get(&Rank::new(QUEEN)).unwrap();
+        let nines = ranked.get(&Rank::new(NINE)).unwrap();
+        let eights = ranked.get(&Rank::new(EIGHT));
+
+        assert_eq!(queens.len(), 4);
+        assert_eq!(nines.len(), 1);
+        assert!(eights.is_none());
+    }
+
     #[test]
     fn map_by_suit() {
         let pile = Pile::french_deck()
@@ -1076,6 +1193,28 @@ mod pile_tests {
         assert_eq!("JB🃟 JL🃟 A♠ K♠".to_string(), sig);
     }
 
+    #[test]
+    fn sort_by_frequency__two_pair() {
+        let pile = Pile::french_deck()
+            .pile_by_index(&["9C", "QS", "9S", "TD", "TH"])
+            .unwrap();
+
+        let actual = pile.sort_by_frequency();
+
+        assert_eq!("T♥ T♦ 9♠ 9♣ Q♠", actual.to_symbol_index())
+    }
+
+    #[test]
+    fn sort_by_frequency__full_house() {
+        let pile = Pile::french_deck()
+            .pile_by_index(&["AD", "2C", "AS", "2S", "2H"])
+            .unwrap();
+
+        let actual = pile.sort_by_frequency();
+
+        assert_eq!("2♠ 2♥ 2♣ A♠ A♦", actual.to_symbol_index())
+    }
+
     #[test]
     fn suits() {
         let deck = Pile::french_deck();
